@@ -945,57 +945,58 @@ get_default_content_type (void)
 static void
 gedit_document_init (GeditDocument *doc)
 {
+	GeditDocumentPrivate *priv;
 	GtkSourceStyleScheme *style_scheme;
-	gint undo_actions;
-	gboolean bracket_matching;
-	gboolean search_hl;
 
 	gedit_debug (DEBUG_DOCUMENT);
 
 	doc->priv = GEDIT_DOCUMENT_GET_PRIVATE (doc);
+	priv = doc->priv;
 
-	doc->priv->editor_settings = g_settings_new ("org.gnome.gedit.preferences.editor");
+	priv->editor_settings = g_settings_new ("org.gnome.gedit.preferences.editor");
 
-	doc->priv->location = NULL;
-	doc->priv->untitled_number = get_untitled_number ();
+	priv->location = NULL;
+	priv->untitled_number = get_untitled_number ();
 
-	doc->priv->metadata_info = NULL;
+	priv->metadata_info = NULL;
 
-	doc->priv->content_type = get_default_content_type ();
+	priv->content_type = get_default_content_type ();
 
-	doc->priv->readonly = FALSE;
+	priv->readonly = FALSE;
 
-	doc->priv->stop_cursor_moved_emission = FALSE;
+	priv->stop_cursor_moved_emission = FALSE;
 
-	doc->priv->last_save_was_manually = TRUE;
-	doc->priv->language_set_by_user = FALSE;
+	priv->last_save_was_manually = TRUE;
+	priv->language_set_by_user = FALSE;
 
-	doc->priv->dispose_has_run = FALSE;
+	priv->dispose_has_run = FALSE;
 
-	doc->priv->mtime.tv_sec = 0;
-	doc->priv->mtime.tv_usec = 0;
+	priv->mtime.tv_sec = 0;
+	priv->mtime.tv_usec = 0;
 
 	g_get_current_time (&doc->priv->time_of_last_save_or_load);
 
-	doc->priv->encoding = gedit_encoding_get_utf8 ();
+	priv->encoding = gedit_encoding_get_utf8 ();
 
-	undo_actions = g_settings_get_int (doc->priv->editor_settings,
-					   GEDIT_SETTINGS_MAX_UNDO_ACTIONS);
-	bracket_matching = g_settings_get_boolean (doc->priv->editor_settings,
-						   GEDIT_SETTINGS_BRACKET_MATCHING);
-	search_hl = g_settings_get_boolean (doc->priv->editor_settings,
-					    GEDIT_SETTINGS_SEARCH_HIGHLIGHTING);
+	g_settings_bind (priv->editor_settings,
+	                 GEDIT_SETTINGS_MAX_UNDO_ACTIONS,
+	                 doc,
+	                 "max-undo-levels",
+	                 G_SETTINGS_BIND_GET);
 
-	gtk_source_buffer_set_max_undo_levels (GTK_SOURCE_BUFFER (doc),
-					       undo_actions);
+	g_settings_bind (priv->editor_settings,
+	                 GEDIT_SETTINGS_BRACKET_MATCHING,
+	                 doc,
+	                 "highlight-matching-brackets",
+	                 G_SETTINGS_BIND_GET);
 
-	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (doc),
-							   bracket_matching);
+	g_settings_bind (priv->editor_settings,
+	                 GEDIT_SETTINGS_SEARCH_HIGHLIGHTING,
+	                 doc,
+	                 "enable-search-highlighting",
+	                 G_SETTINGS_BIND_GET);
 
-	gedit_document_set_enable_search_highlighting (doc,
-						       search_hl);
-
-	style_scheme = get_default_style_scheme (doc->priv->editor_settings);
+	style_scheme = get_default_style_scheme (priv->editor_settings);
 	if (style_scheme != NULL)
 		gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (doc),
 						    style_scheme);
@@ -2486,11 +2487,11 @@ static void
 get_style_colors (GeditDocument *doc,
                   const gchar   *style_name,
                   gboolean      *foreground_set,
-                  GdkColor      *foreground,
+                  GdkRGBA       *foreground,
                   gboolean      *background_set,
-                  GdkColor      *background,
+                  GdkRGBA       *background,
                   gboolean      *line_background_set,
-                  GdkColor      *line_background,
+                  GdkRGBA       *line_background,
                   gboolean      *bold_set,
                   gboolean      *bold,
                   gboolean      *italic_set,
@@ -2534,7 +2535,7 @@ get_style_colors (GeditDocument *doc,
 
 	if (*foreground_set)
 	{
-		if (fg == NULL || !gdk_color_parse (fg, foreground))
+		if (fg == NULL || !gdk_rgba_parse (foreground, fg))
 		{
 			*foreground_set = FALSE;
 		}
@@ -2543,7 +2544,7 @@ get_style_colors (GeditDocument *doc,
 	if (*background_set)
 	{
 		if (bg == NULL ||
-		    !gdk_color_parse (bg, background))
+		    !gdk_rgba_parse (background, bg))
 		{
 			*background_set = FALSE;
 		}
@@ -2552,7 +2553,7 @@ get_style_colors (GeditDocument *doc,
 	if (*line_background_set)
 	{
 		if (line_bg == NULL ||
-		    !gdk_color_parse (line_bg, background))
+		    !gdk_rgba_parse (line_background, line_bg))
 		{
 			*line_background_set = FALSE;
 		}
@@ -2569,7 +2570,7 @@ get_style_colors (GeditDocument *doc,
 			     "Falling back to hard-coded colors "
 			     "for the \"found\" text tag.");
 
-	gdk_color_parse ("#FFFF78", background);
+	gdk_rgba_parse (background, "#FFFF78");
 	*background_set = TRUE;
 	*foreground_set = FALSE;
 
@@ -2581,9 +2582,9 @@ sync_tag_style (GeditDocument *doc,
                 GtkTextTag    *tag,
                 const gchar   *style_name)
 {
-	GdkColor fg;
-	GdkColor bg;
-	GdkColor line_bg;
+	GdkRGBA fg;
+	GdkRGBA bg;
+	GdkRGBA line_bg;
 	gboolean fg_set;
 	gboolean bg_set;
 	gboolean line_bg_set;
@@ -2613,9 +2614,9 @@ sync_tag_style (GeditDocument *doc,
 	g_object_freeze_notify (G_OBJECT (tag));
 
 	g_object_set (tag,
-	              "foreground-gdk", fg_set ? &fg : NULL,
-	              "background-gdk", bg_set ? &bg : NULL,
-	              "paragraph-background-gdk", line_bg_set ? &line_bg : NULL,
+	              "foreground-rgba", fg_set ? &fg : NULL,
+	              "background-rgba", bg_set ? &bg : NULL,
+	              "paragraph-background-rgba", line_bg_set ? &line_bg : NULL,
 	              "weight", bold_set && bold ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL,
 	              "style", italic_set && italic ? PANGO_STYLE_ITALIC : PANGO_STYLE_NORMAL,
 	              "underline", underline_set && underline ? PANGO_UNDERLINE_SINGLE : PANGO_UNDERLINE_NONE,
