@@ -18,7 +18,6 @@
 
 import os
 from gi.repository import Gio, Gtk, Gdk, GtkSource, Gedit
-from .outputpanel import OutputPanel
 from .capture import *
 
 def default(val, d):
@@ -39,6 +38,20 @@ def current_word(document):
             
     return (start, piter)
 
+def file_browser_root(window):
+    bus = window.get_message_bus()
+
+    if bus.is_registered('/plugins/filebrowser', 'get_root'):
+        msg = bus.send_sync('/plugins/filebrowser', 'get_root')
+
+        if msg:
+            browser_root = msg.props.location
+
+            if browser_root and browser_root.is_native():
+                return browser_root.get_path()
+                
+    return None
+
 # ==== Capture related functions ====
 def run_external_tool(window, panel, node):
     # Configure capture environment
@@ -107,6 +120,11 @@ def run_external_tool(window, panel, node):
         capture.set_env(GEDIT_DOCUMENTS_URI  = ' '.join(documents_uri),
                         GEDIT_DOCUMENTS_PATH = ' '.join(documents_path))
 
+    # set file browser root env var if possible
+    browser_root = file_browser_root(window)
+    if browser_root:
+        capture.set_env(GEDIT_FILE_BROWSER_ROOT = browser_root)
+
     flags = capture.CAPTURE_BOTH
     
     if not node.has_hash_bang():
