@@ -196,6 +196,8 @@ static void model_check_dummy                               (GeditFileBrowserSto
 static void next_files_async 				    (GFileEnumerator        *enumerator,
 							     AsyncNode              *async);
 
+static void delete_files                                    (AsyncData              *data);
+
 G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBrowserStore, gedit_file_browser_store,
 				G_TYPE_OBJECT,
 				0,
@@ -313,6 +315,9 @@ gedit_file_browser_store_set_property (GObject      *object,
 
 	switch (prop_id)
 	{
+		case PROP_ROOT:
+			gedit_file_browser_store_set_root (obj, G_FILE (g_value_get_object (value)));
+			break;
 		case PROP_FILTER_MODE:
 			gedit_file_browser_store_set_filter_mode (obj,
 			                                          g_value_get_flags (value));
@@ -338,7 +343,7 @@ gedit_file_browser_store_class_init (GeditFileBrowserStoreClass *klass)
 					 		      "Root",
 					 		      "The root location",
 					 		      G_TYPE_FILE,
-					 		      G_PARAM_READABLE));
+					 		      G_PARAM_CONSTRUCT | G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_VIRTUAL_ROOT,
 					 g_param_spec_object ("virtual-root",
@@ -1094,6 +1099,12 @@ model_sort_default (FileBrowserNode *node1,
 	if (f1 != f2)
 		return f1 ? -1 : 1;
 
+	f1 = NODE_IS_HIDDEN (node1);
+	f2 = NODE_IS_HIDDEN (node2);
+
+	if (f1 != f2)
+		return f2 ? -1 : 1;
+
 	return collate_nodes (node1, node2);
 }
 
@@ -1658,10 +1669,6 @@ model_recomposite_icon_real (GeditFileBrowserStore *tree_model,
 		icon = gedit_file_browser_utils_pixbuf_from_file (node->file, GTK_ICON_SIZE_MENU, FALSE);
 	}
 
-	/* Fallback to the same icon as the file browser */
-	if (!icon)
-		icon = gedit_file_browser_utils_pixbuf_from_theme ("text-x-generic", GTK_ICON_SIZE_MENU);
-
 	if (node->icon)
 		g_object_unref (node->icon);
 
@@ -2966,13 +2973,9 @@ model_mount_root (GeditFileBrowserStore *model,
 GeditFileBrowserStore *
 gedit_file_browser_store_new (GFile *root)
 {
-	GeditFileBrowserStore *obj =
-	    GEDIT_FILE_BROWSER_STORE (g_object_new
-				      (GEDIT_TYPE_FILE_BROWSER_STORE,
-				       NULL));
-
-	gedit_file_browser_store_set_root (obj, root);
-	return obj;
+	return GEDIT_FILE_BROWSER_STORE (g_object_new (GEDIT_TYPE_FILE_BROWSER_STORE,
+	                                               "root", root,
+	                                               NULL));
 }
 
 void
@@ -3519,84 +3522,101 @@ emit_no_trash (AsyncData *data)
 	return ret;
 }
 
-typedef struct {
-	GeditFileBrowserStore *model;
-	GFile *file;
-} IdleDelete;
-
-static gboolean
-file_deleted (IdleDelete *data)
+static void
+delete_file_finished (GFile        *file,
+		      GAsyncResult *res,
+		      AsyncData    *data)
 {
-	FileBrowserNode *node;
-	node = model_find_node (data->model, NULL, data->file);
-
-	if (node != NULL)
-		model_remove_node (data->model, node, NULL, TRUE);
-
-	return FALSE;
-}
-
-static gboolean
-delete_files (GIOSchedulerJob *job,
-	      GCancellable    *cancellable,
-	      AsyncData       *data)
-{
-	GFile *file;
 	GError *error = NULL;
-	gboolean ret;
-	gint code;
-	IdleDelete delete;
-
-	/* Check if our job is done */
-	if (!data->iter)
-		return FALSE;
-
-	/* Move a file to the trash */
-	file = G_FILE (data->iter->data);
+	gboolean ok;
 
 	if (data->trash)
-		ret = g_file_trash (file, cancellable, &error);
-	else
-		ret = g_file_delete (file, cancellable, &error);
-
-	if (ret)
 	{
-		delete.model = data->model;
-		delete.file = file;
-
-		/* Remove the file from the model in the main loop */
-		g_io_scheduler_job_send_to_mainloop (job, (GSourceFunc)file_deleted, &delete, NULL);
+		ok = g_file_trash_finish (file, res, &error);
 	}
-	else if (!ret && error)
+	else
 	{
-		code = error->code;
+		ok = g_file_delete_finish (file, res, &error);
+	}
+
+	if (ok)
+	{
+		/* Remove the file from the model */
+		FileBrowserNode *node = model_find_node (data->model, NULL, file);
+
+		if (node != NULL)
+		{
+			model_remove_node (data->model, node, NULL, TRUE);
+		}
+
+		/* Process the next file */
+		data->iter = data->iter->next;
+	}
+	else if (!ok && error != NULL)
+	{
+		gint code = error->code;
 		g_error_free (error);
 
 		if (data->trash && code == G_IO_ERROR_NOT_SUPPORTED)
 		{
-			/* Trash is not supported on this system ... */
-			if (g_io_scheduler_job_send_to_mainloop (job, (GSourceFunc)emit_no_trash, data, NULL))
+			/* Trash is not supported on this system. Ask the user
+			 * if he wants to delete completely the files instead.
+			 */
+			if (emit_no_trash (data))
 			{
 				/* Changes this into a delete job */
 				data->trash = FALSE;
 				data->iter = data->files;
-
-				return TRUE;
 			}
-
-			/* End the job */
-			return FALSE;
+			else
+			{
+				/* End the job */
+				async_data_free (data);
+				return;
+			}
 		}
 		else if (code == G_IO_ERROR_CANCELLED)
 		{
-			/* Job has been cancelled, just let the job end */
-			return FALSE;
+			/* Job has been cancelled, end the job */
+			async_data_free (data);
+			return;
 		}
 	}
 
-	/* Process the next item */
-	data->iter = data->iter->next;
-	return TRUE;
+	/* Continue the job */
+	delete_files (data);
+}
+
+static void
+delete_files (AsyncData *data)
+{
+	GFile *file;
+
+	/* Check if our job is done */
+	if (data->iter == NULL)
+	{
+		async_data_free (data);
+		return;
+	}
+
+	file = G_FILE (data->iter->data);
+
+	if (data->trash)
+	{
+		g_file_trash_async (file,
+				    G_PRIORITY_DEFAULT,
+				    data->cancellable,
+				    (GAsyncReadyCallback)delete_file_finished,
+				    data);
+	}
+	else
+	{
+		g_file_delete_async (file,
+				     G_PRIORITY_DEFAULT,
+				     data->cancellable,
+				     (GAsyncReadyCallback)delete_file_finished,
+				     data);
+	}
 }
 
 GeditFileBrowserStoreResult
@@ -3650,11 +3670,7 @@ gedit_file_browser_store_delete_all (GeditFileBrowserStore *model,
 
 	model->priv->async_handles = g_slist_prepend (model->priv->async_handles, data);
 
-	g_io_scheduler_push_job ((GIOSchedulerJobFunc)delete_files,
-				 data,
-				 (GDestroyNotify)async_data_free,
-				 G_PRIORITY_DEFAULT,
-				 data->cancellable);
+	delete_files (data);
 	g_list_free (rows);
 
 	return GEDIT_FILE_BROWSER_STORE_RESULT_OK;
@@ -3706,7 +3722,7 @@ gedit_file_browser_store_new_file (GeditFileBrowserStore *model,
 
 	parent_node = FILE_BROWSER_NODE_DIR (parent->user_data);
 	/* Translators: This is the default name of new files created by the file browser pane. */
-	file = unique_new_name (((FileBrowserNode *) parent_node)->file, _("file"));
+	file = unique_new_name (((FileBrowserNode *) parent_node)->file, _("Untitled File"));
 
 	stream = g_file_create (file, G_FILE_CREATE_NONE, NULL, &error);
 
@@ -3765,7 +3781,7 @@ gedit_file_browser_store_new_directory (GeditFileBrowserStore *model,
 
 	parent_node = FILE_BROWSER_NODE_DIR (parent->user_data);
 	/* Translators: This is the default name of new directories created by the file browser pane. */
-	file = unique_new_name (((FileBrowserNode *) parent_node)->file, _("directory"));
+	file = unique_new_name (((FileBrowserNode *) parent_node)->file, _("Untitled Folder"));
 
 	if (!g_file_make_directory (file, NULL, &error))
 	{
